==> kadu_0.11.2.orig.tar.bz2: kadu-0.11.2/plugins/cenzor/translations/cenzor_it.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="it" version="2.0">
<context>
    <name>@default</name>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="4"/>
        <source>Chat</source>
        <translation>Chat</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="7"/>
        <source>Cenzor</source>
        <translation>Censura</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="10"/>
        <source>General</source>
        <translation>Generale</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="13"/>
        <source>Enable cenzor</source>
        <translation>Abilita censura</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="16"/>
        <source>Admonition</source>
        <translation>Ammonizione</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="21"/>
        <source>Swearwords</source>
        <translation>Parolaccie</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="25"/>
        <source>Exclusions</source>
        <translation>Esclusioni</translation>
    </message>
</context>
<context>
    <name>CenzorNotification</name>
    <message>
        <location filename="../notify/cenzor-notification.cpp" line="50"/>
        <source>Message was cenzored</source>
        <translation>Il messaggio è stato censurato</translation>
    </message>
    <message>
        <location filename="../notify/cenzor-notification.cpp" line="52"/>
        <source>Your interlocutor used obscene word and became admonished</source>
        <translation>Il tuo interlocutore ha usato parole oscene e sarà ammonito</translation>
    </message>
</context>
<context>
    <name>ListEditWidget</name>
    <message>
        <location filename="../gui/widgets/list-edit-widget.cpp" line="48"/>
        <source>Add</source>
        <translation>Aggiungi</translation>
    </message>
    <message>
        <location filename="../gui/widgets/list-edit-widget.cpp" line="49"/>
        <source>Change</source>
        <translation>Cambia</translation>
    </message>
    <message>
        <location filename="../gui/widgets/list-edit-widget.cpp" line="50"/>
        <source>Delete</source>
        <translation>Cancella</translation>
    </message>
</context>
</TS>

==> kadu_0.12.3.orig.tar.bz2: kadu-0.12.3/plugins/cenzor/translations/cenzor_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="it">
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation>Chat</translation>
    </message>
    <message>
        <source>Cenzor</source>
        <translation>Censura</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Generale</translation>
    </message>
    <message>
        <source>Enable cenzor</source>
        <translation>Abilita censura</translation>
    </message>
    <message>
        <source>Admonition</source>
        <translation>Ammonizione</translation>
    </message>
    <message>
        <source>Swearwords</source>
        <translation>Parolaccie</translation>
    </message>
    <message>
        <source>Exclusions</source>
        <translation>Esclusioni</translation>
    </message>
    <message>
        <source>Message was cenzored</source>
        <translation type="unfinished">Il messaggio è stato censurato</translation>
    </message>
</context>
<context>
    <name>CenzorNotification</name>
    <message>
        <source>Message was cenzored</source>
        <translation>Il messaggio è stato censurato</translation>
    </message>
    <message>
        <source>Your interlocutor used obscene word and became admonished</source>
        <translation>Il tuo interlocutore ha usato parole oscene e sarà ammonito</translation>
    </message>
    <message>
        <source>Cenzor</source>
        <translation type="unfinished">Censura</translation>
    </message>
</context>
<context>
    <name>ListEditWidget</name>
    <message>
        <source>Add</source>
        <translation>Aggiungi</translation>
    </message>
    <message>
        <source>Change</source>
        <translation>Cambia</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Cancella</translation>
    </message>
</context>
</TS>
